package org.openqa.selenium.devtools.v103.audits.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * Represents the failure reason when a federated authentication reason fails.
 * Should be updated alongside RequestIdTokenStatus in
 * third_party/blink/public/mojom/devtools/inspector_issue.mojom to include
 * all cases except for success.
 */
public enum FederatedAuthRequestIssueReason {

    APPROVALDECLINED("ApprovalDeclined"),
    TOOMANYREQUESTS("TooManyRequests"),
    MANIFESTLISTHTTPNOTFOUND("ManifestListHttpNotFound"),
    MANIFESTLISTNORESPONSE("ManifestListNoResponse"),
    MANIFESTLISTINVALIDRESPONSE("ManifestListInvalidResponse"),
    MANIFESTNOTINMANIFESTLIST("ManifestNotInManifestList"),
    MANIFESTLISTTOOBIG("ManifestListTooBig"),
    MANIFESTHTTPNOTFOUND("ManifestHttpNotFound"),
    MANIFESTNORESPONSE("ManifestNoResponse"),
    MANIFESTINVALIDRESPONSE("ManifestInvalidResponse"),
    CLIENTMETADATAHTTPNOTFOUND("ClientMetadataHttpNotFound"),
    CLIENTMETADATANORESPONSE("ClientMetadataNoResponse"),
    CLIENTMETADATAINVALIDRESPONSE("ClientMetadataInvalidResponse"),
    CLIENTMETADATAMISSINGPRIVACYPOLICYURL("ClientMetadataMissingPrivacyPolicyUrl"),
    DISABLEDINSETTINGS("DisabledInSettings"),
    ERRORFETCHINGSIGNIN("ErrorFetchingSignin"),
    INVALIDSIGNINRESPONSE("InvalidSigninResponse"),
    ACCOUNTSHTTPNOTFOUND("AccountsHttpNotFound"),
    ACCOUNTSNORESPONSE("AccountsNoResponse"),
    ACCOUNTSINVALIDRESPONSE("AccountsInvalidResponse"),
    IDTOKENHTTPNOTFOUND("IdTokenHttpNotFound"),
    IDTOKENNORESPONSE("IdTokenNoResponse"),
    IDTOKENINVALIDRESPONSE("IdTokenInvalidResponse"),
    IDTOKENINVALIDREQUEST("IdTokenInvalidRequest"),
    ERRORIDTOKEN("ErrorIdToken"),
    CANCELED("Canceled");

    private String value;

    FederatedAuthRequestIssueReason(String value) {
        this.value = value;
    }

    public static FederatedAuthRequestIssueReason fromString(String s) {
        return java.util.Arrays.stream(FederatedAuthRequestIssueReason.values()).filter(rs -> rs.value.equalsIgnoreCase(s)).findFirst().orElseThrow(() -> new org.openqa.selenium.devtools.DevToolsException("Given value " + s + " is not found within FederatedAuthRequestIssueReason "));
    }

    public String toString() {
        return value;
    }

    public String toJson() {
        return value;
    }

    private static FederatedAuthRequestIssueReason fromJson(JsonInput input) {
        return fromString(input.nextString());
    }
}
